OiRA

# Zertifikat

This certificate is presented to

Sacrebleu & Fils

For conducting a risk assessment with the tool “Transport routier” on 7 September 2019.

Name on certificate Departement/Region SIRET number Contact name
Make public

Your certificate for “Buckets and broomsticks” is private unless you choose to make it public. By ticking the “Make public” tickbox above, your certificate will be published on the official OiRA website.

Back

## certificate-public.html

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Loading Risk Assessments…